#
# spec file for package perl-Clone-PP
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Clone-PP
Version:        1.08
Release:        1.14
%define cpan_name Clone-PP
Summary:        Recursively copy Perl datatypes
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/N/NE/NEILB/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
This module provides a general-purpose clone function to make deep copies
of Perl data structures. It calls itself recursively to copy nested hash,
array, scalar and reference types, including tied variables and objects.

The clone() function takes a scalar argument to copy. To duplicate arrays
or hashes, pass them in by reference:

  my $copy = clone(\@array);    my @copy = @{ clone(\@array) };
  my $copy = clone(\%hash);     my %copy = %{ clone(\%hash) };

The clone() function also accepts an optional second parameter that can be
used to limit the depth of the copy. If you pass a limit of 0, clone will
return the same value you supplied; for a limit of 1, a shallow copy is
constructed; for a limit of 2, two layers of copying are done, and so on.

  my $shallow_copy = clone( $item, 1 );

To allow objects to intervene in the way they are copied, the clone()
function checks for a couple of optional methods. If an object provides a
method named 'clone_self', it is called and the result returned without
further processing. Alternately, if an object provides a method named
'clone_init', it is called on the copied object before it is returned.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README

%changelog
* Wed Oct 21 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.08
  see /usr/share/doc/packages/perl-Clone-PP/Changes
  1.08 2020-10-20 NEILB
  - Changed "sub main'dump" to "sub main::dump" in t/dump.pl, as that
    meant this distribution wouldn't build under cperl. RT#125171
* Tue Apr 11 2017 coolo@suse.com
- updated to 1.07
  see /usr/share/doc/packages/perl-Clone-PP/Changes
  1.07 2017-04-10 NEILB
  - Update tests to cope with '.' not being in @INC, part of Perl 5.26.
    Thanks to Jim Keenan for the PR which fixed this.
* Mon Jul 28 2014 coolo@suse.com
- updated to 1.06
  - Changed the copyright on dclone.t, dump.pl, and tied.pl in t/,
    to match the rest of the dist, "same as perl itself".
    These changes were approved by the copyright owner, Raphael Manfredi.
* Fri Mar  7 2014 coolo@suse.com
- updated to 1.05
  - Added github repo to metadata (thanks dsteinbrunner)
  - Added github repo to doc
  - I had erroneously listed Test::Array as a test prereq,
    but the package is defined in 01array.t where it's used.
    RT#93082 - thanks to Dagfinn Ilmari Mannsaker.
  - Added Changes file
  - Fixed typos from dsteinbrunner in RT#86337
  - Added "use warnings" and in the process fixed RT#17121
  - Min perl version 5.6.0 in code and metadata
  - Added license type to metadata and renamed L&C section in pod
  - Expanded the SEE ALSO section
  - Added prereqs to PREREQ_PM in Makefile.PL
  - Added test prereqs in TEST_REQUIRES
* Fri Nov 11 2011 coolo@suse.com
- use original source
* Mon Apr 11 2011 jw@novell.com
- suggesting NoSource, to resolve BNC#686233
* Wed Apr  6 2011 coolo@novell.com
- fix license ("same terms as Perl")
* Thu Feb 17 2011 jw@novell.com
- initial pull from CPAN with cpanspec_obs
- needed by Rose::DB
* Thu Feb 17 2011 jw@novell.com
- initial package 1.02
  * created by cpanspec 1.78.03
